
<div class="row">
    <div class="form-group col-md-6">
        <label for="activityUserId">User ID</label>

        <div class="input-group">
            <input type="text" class="form-control" id="activityUserId"
                   [(ngModel)]="userId">

            <span class="input-group-btn">
                <button class="btn btn-default" (click)="update()">Update</button>
            </span>
        </div>
    </div>
</div>

<h1 *ngIf="activities.length === 0">There are no activity items.</h1>

<table class="table table-striped" *ngIf="activities.length !== 0">
    <thead>
    <tr>
        <td>Date</td>
        <td>Title</td>
        <td>Description</td>
    </tr>
    </thead>
    <tbody>
    <tr *ngFor="let activity of activities" (click)="activityClicked(activity)">
        <td>{{activity.dateTime}}</td>
        <td>{{activity.title}}</td>
        <td>{{activity.description}}</td>
    </tr>
    </tbody>
</table>
